@@ -174,7 +174,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
             log_group_props=log_group_props,
         )
 
-        jsii.create(KinesisStreamsToKinesisFirehoseToS3, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisFirehose")
